ProSHADE: Namespace Members

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

Here is a list of all documented namespace members with links to the namespaces they belong to:

### - c -

- changeFourierOrder() : ProSHADE_internal_mapManip
- changePDBBFactors() : ProSHADE_internal_mapManip
- checkDistancesSettings() : ProSHADE_internal_tasks
- checkExpectedAgainstFound() : ProSHADE_internal_symmetry
- checkFittingAxisDualAndSave() : ProSHADE_internal_symmetry
- checkFittingAxisTripleAndSave() : ProSHADE_internal_symmetry
- checkForMissingPeak() : ProSHADE_internal_symmetry
- checkMapManipulationSettings() : ProSHADE_internal_tasks
- checkMemoryAllocation() : ProSHADE_internal_misc
- checkOverlaySettings() : ProSHADE_internal_tasks
- checkSymmetrySettings() : ProSHADE_internal_tasks
- combineFourierForTranslation() : ProSHADE_internal_overlay
- completeLegendreSeries() : ProSHADE_internal_maths
- completeMissingCSymmetry() : ProSHADE_internal_symmetry
- complexMatrixSVDSigmasOnly() : ProSHADE_internal_maths
- complexMatrixSVDUandVOnly() : ProSHADE_internal_maths
- complexMultiplication() : ProSHADE_internal_maths
- complexMultiplicationConjug() : ProSHADE_internal_maths
- complexMultiplicationConjugRealOnly() : ProSHADE_internal_maths
- complexMultiplicationRealOnly() : ProSHADE_internal_maths
- compute3x3MatrixInverse() : ProSHADE_internal_maths
- compute3x3MatrixMultiplication() : ProSHADE_internal_maths
- compute3x3MatrixVectorMultiplication() : ProSHADE_internal_maths
- computeAngularThreshold() : ProSHADE_internal_overlay
- computeBeforeAfterZeroCounts() : ProSHADE_internal_overlay
- computeCrossProduct() : ProSHADE_internal_maths
- computeDotProduct() : ProSHADE_internal_maths
- computeEMatrices() : ProSHADE_internal_distances
- computeEMatricesForLM() : ProSHADE_internal_distances
- computeEnergyLevelsDescriptor() : ProSHADE_internal_distances
- computeGroupElementsForGroup() : ProSHADE_internal_data
- computeInverseSOFTTransform() : ProSHADE_internal_distances
- computeRotationunctionDescriptor() : ProSHADE_internal_distances
- computeRRPPearsonCoefficients() : ProSHADE_internal_distances
- computeSphericalHarmonics() : ProSHADE_internal_sphericalHarmonics
- computeSphericalHarmonicsMagnitude() : ProSHADE_internal_distances
- computeSphericalTransformCoeffs() : ProSHADE_internal_sphericalHarmonics
- computeTraceSigmaDescriptor() : ProSHADE_internal_distances
- computeWeightsForEMatricesForLM() : ProSHADE_internal_distances
- computeWignerMatrices() : ProSHADE_internal_wigner
- computeWignerMatricesForRotation() : ProSHADE_internal_wigner
- connectMaskBlobs() : ProSHADE_internal_mapManip
- copyMapByBounds() : ProSHADE_internal_mapManip